@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -25,6 +25,8 @@ typedef unsigned long intptr_t;
 #include "Context.h"
 #include "robustPredicates.h"
 #include "BasisFactory.h"
+#include "gmshCrossFields.h"
+
 
 #if defined(HAVE_PARSER)
 #include "Parser.h"
@@ -343,6 +345,14 @@ int GmshBatch()
         (CTX::instance()->batchSomeValue * M_PI / 180., true, true, M_PI);
       GModel::current()->createGeometryOfDiscreteEntities();
     }
+    else if(CTX::instance()->batch == 69){
+      std::vector<int> tags;
+      computeCrossField (GModel::current(), tags);
+      GoodbyeMessage();
+      CTX::instance()->batch =0;
+      // still a bug in allocation somewhere
+      exit(0);
+    }
 #endif
   }
 
