@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _ACIS_EDGE_H_
-#define _ACIS_EDGE_H_
+#ifndef ACIS_EDGE_H
+#define ACIS_EDGE_H
 
 #include "GmshConfig.h"
 #include "GEdge.h"
