@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -738,6 +738,7 @@ static void meshCompound(GEdge *ge)
   // no new mesh nodes are created here
   discreteEdge *de = new discreteEdge(ge->model(), ge->tag() + 100000);
   ge->model()->add(de);
+  std::vector<int> phys;
   for(std::size_t i = 0; i < ge->compound.size(); i++) {
     GEdge *c = (GEdge *)ge->compound[i];
     // cannot use the same line elements, as they get deleted in createGeometry
@@ -746,6 +747,8 @@ static void meshCompound(GEdge *ge)
                                     c->lines[j]->getVertex(1)));
     }
     c->compoundCurve = de;
+    phys.insert(phys.end(), c->physicals.begin(), c->physicals.end());
+    c->physicals.clear();
   }
   // create the geometry of the compound
   de->createGeometry(true);
@@ -758,6 +761,7 @@ static void meshCompound(GEdge *ge)
   de->deleteVertexArrays();
   // mesh the compound
   de->mesh(false);
+  de->physicals = phys;
 }
 #endif
 
