@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -1486,6 +1486,7 @@ static void meshCompound(GFace *gf, bool verbose)
 
   std::set<GEdge*, GEntityPtrLessThan> bnd, emb1;
   std::set<GVertex*, GEntityPtrLessThan> emb0;
+  std::vector<int> phys;
   for(std::size_t i = 0; i < gf->compound.size(); i++) {
     GFace *c = (GFace *)gf->compound[i];
     df->triangles.insert(df->triangles.end(), c->triangles.begin(),
@@ -1515,6 +1516,10 @@ static void meshCompound(GFace *gf, bool verbose)
       c->mesh_vertices.clear();
     }
     c->compoundSurface = df;
+    if(!magic) {
+      phys.insert(phys.end(), c->physicals.begin(), c->physicals.end());
+      c->physicals.clear();
+    }
   }
 
   std::set<GEdge*, GEntityPtrLessThan> bndc;
@@ -1550,6 +1555,7 @@ static void meshCompound(GFace *gf, bool verbose)
   df->mesh(verbose);
 
   if(!magic){
+    df->physicals = phys;
     return;
   }
 
@@ -1798,6 +1804,7 @@ void GFace::setMeshMaster(GFace *master, const std::vector<double> &tfo)
     int numb = m_vtxToEdge.count(backward);
     int sign = 0;
     GEdge *masterEdge = 0;
+
     if(numf == 1){
       masterEdge = m_vtxToEdge.find(forward)->second;
       sign = 1;
@@ -1815,7 +1822,9 @@ void GFace::setMeshMaster(GFace *master, const std::vector<double> &tfo)
           it != ret.second; it++){
         SBoundingBox3d masterbb = it->second->bounds(true);
         masterbb.transform(tfo);
-        masterbb *= (1. + CTX::instance()->geom.tolerance);
+        double tol = CTX::instance()->geom.tolerance * CTX::instance()->lc;
+        masterbb += (masterbb.min() - SPoint3(tol, tol, tol));
+        masterbb += (masterbb.max() + SPoint3(tol, tol, tol));
         if(masterbb.contains(localbb)){
           masterEdge = it->second;
           sign = 1;
@@ -1832,7 +1841,9 @@ void GFace::setMeshMaster(GFace *master, const std::vector<double> &tfo)
           it != ret.second; it++){
         SBoundingBox3d masterbb = it->second->bounds(true);
         masterbb.transform(tfo);
-        masterbb *= (1. + CTX::instance()->geom.tolerance);
+        double tol = CTX::instance()->geom.tolerance * CTX::instance()->lc;
+        masterbb += (masterbb.min() - SPoint3(tol, tol, tol));
+        masterbb += (masterbb.max() + SPoint3(tol, tol, tol));
         if(masterbb.contains(localbb)){
           masterEdge = it->second;
           sign = -1;
@@ -1842,10 +1853,10 @@ void GFace::setMeshMaster(GFace *master, const std::vector<double> &tfo)
     }
 
     if(!masterEdge){
-      Msg::Error("Could not find counterpart of curve with end points %d-%d "
+      Msg::Error("Could not find counterpart of curve %d with end points %d-%d "
                  "(corresponding to curve with end points %d %d) in surface %d",
-                 lPair.first->tag(), lPair.second->tag(), forward.first->tag(),
-                 forward.second->tag(), master->tag());
+                 localEdge->tag(), lPair.first->tag(), lPair.second->tag(),
+                 forward.first->tag(), forward.second->tag(), master->tag());
       return;
     }
 
