@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -543,8 +543,12 @@ void meshGEdge::operator()(GEdge *ge)
 
   ge->model()->setCurrentMeshEntity(ge);
 
-  if(ge->degenerate(1) ||
-     (ge->geomType() == GEntity::BoundaryLayerCurve) ||
+  if (ge->degenerate(1)) {
+    ge->meshStatistics.status = GEdge::DONE;
+    return;
+  }
+
+  if ((ge->geomType() == GEntity::BoundaryLayerCurve) ||
      (ge->meshAttributes.method == MESH_NONE) ||
      (CTX::instance()->mesh.meshOnlyVisible && !ge->getVisibility())) {
     return;
