@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "Lambda2.h"
 #include "Numeric.h"
@@ -73,7 +73,7 @@ static void eigen(std::vector<double> &inList, int inNb,
 
   // loop on elements
   int nb = inList.size() / inNb;
-  for(unsigned int i = 0; i < inList.size(); i += nb) {
+  for(std::size_t i = 0; i < inList.size(); i += nb) {
     // copy node coordinates
     for(int j = 0; j < 3 * nbNod; j++) outList.push_back(inList[i + j]);
 
