@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "eigenSolver.h"
 #include "OS.h"
@@ -19,30 +19,30 @@ void eigenSolver::_check(int ierr) const { CHKERRABORT(PETSC_COMM_WORLD, ierr);
 
 eigenSolver::eigenSolver(dofManager<double> *manager, std::string A,
                          std::string B, bool hermitian)
-  : _A(0), _B(0), _hermitian(hermitian)
+  : _sysA(0), _sysB(0), _hermitian(hermitian)
 {
   if(A.size()) {
-    _A = dynamic_cast<linearSystemPETSc<double> *>(manager->getLinearSystem(A));
-    if(!_A) Msg::Error("Could not find PETSc system '%s'", A.c_str());
+    _sysA = dynamic_cast<linearSystemPETSc<double> *>(manager->getLinearSystem(A));
+    if(!_sysA) Msg::Error("Could not find PETSc system '%s'", A.c_str());
   }
   if(B.size()) {
-    _B = dynamic_cast<linearSystemPETSc<double> *>(manager->getLinearSystem(B));
-    if(!_B) Msg::Error("Could not find PETSc system '%s'", B.c_str());
+    _sysB = dynamic_cast<linearSystemPETSc<double> *>(manager->getLinearSystem(B));
+    if(!_sysB) Msg::Error("Could not find PETSc system '%s'", B.c_str());
   }
 }
 
 eigenSolver::eigenSolver(linearSystemPETSc<double> *A,
                          linearSystemPETSc<double> *B, bool hermitian)
-  : _A(A), _B(B), _hermitian(hermitian)
+  : _sysA(A), _sysB(B), _hermitian(hermitian)
 {
 }
 
 bool eigenSolver::solve(int numEigenValues, std::string which,
                         std::string method, double tolVal, int iterMax)
 {
-  if(!_A) return false;
-  Mat A = _A->getMatrix();
-  Mat B = _B ? _B->getMatrix() : PETSC_NULL;
+  if(!_sysA) return false;
+  Mat A = _sysA->getMatrix();
+  Mat B = _sysB ? _sysB->getMatrix() : PETSC_NULL;
 
   PetscInt N, M;
   _check(MatAssemblyBegin(A, MAT_FINAL_ASSEMBLY));
@@ -50,7 +50,7 @@ bool eigenSolver::solve(int numEigenValues, std::string which,
   _check(MatGetSize(A, &N, &M));
 
   PetscInt N2, M2;
-  if(_B) {
+  if(_sysB) {
     _check(MatAssemblyBegin(B, MAT_FINAL_ASSEMBLY));
     _check(MatAssemblyEnd(B, MAT_FINAL_ASSEMBLY));
     _check(MatGetSize(B, &N2, &M2));
@@ -61,9 +61,9 @@ bool eigenSolver::solve(int numEigenValues, std::string which,
   _check(EPSCreate(PETSC_COMM_WORLD, &eps));
   _check(EPSSetOperators(eps, A, B));
   if(_hermitian)
-    _check(EPSSetProblemType(eps, _B ? EPS_GHEP : EPS_HEP));
+    _check(EPSSetProblemType(eps, _sysB ? EPS_GHEP : EPS_HEP));
   else
-    _check(EPSSetProblemType(eps, _B ? EPS_GNHEP : EPS_NHEP));
+    _check(EPSSetProblemType(eps, _sysB ? EPS_GNHEP : EPS_NHEP));
 
   // set some default options
   _check(EPSSetDimensions(eps, numEigenValues, PETSC_DECIDE, PETSC_DECIDE));
@@ -76,8 +76,10 @@ bool eigenSolver::solve(int numEigenValues, std::string which,
     _check(EPSSetType(eps, EPSARPACK));
   else if(method == "power")
     _check(EPSSetType(eps, EPSPOWER));
-  else
-    Msg::Fatal("eigenSolver: method '%s' not available", method.c_str());
+  else{
+    Msg::Error("eigenSolver: method '%s' not available", method.c_str());
+    _check(EPSSetType(eps, EPSKRYLOVSCHUR));
+  }
 
   // override these options at runtime, petsc-style
   _check(EPSSetFromOptions(eps));
@@ -207,10 +209,10 @@ bool eigenSolver::solve(int numEigenValues, std::string which,
 void eigenSolver::normalize_mode(std::vector<int> modeView, double scale)
 {
   Msg::Info("Normalize all eigenvectors");
-  for(unsigned int imode = 0; imode < modeView.size(); imode++) {
+  for(std::size_t imode = 0; imode < modeView.size(); imode++) {
     int i = modeView[imode];
     double norm = 0.;
-    for(unsigned int j = 0; j < _eigenVectors[i].size(); j++) {
+    for(std::size_t j = 0; j < _eigenVectors[i].size(); j++) {
       std::complex<double> val = _eigenVectors[i][j];
       double normval = std::abs(val);
       if(normval > norm) norm = normval;
@@ -219,7 +221,7 @@ void eigenSolver::normalize_mode(std::vector<int> modeView, double scale)
       Msg::Error("zero eigenvector");
       return;
     }
-    for(unsigned int j = 0; j < _eigenVectors[i].size(); j++) {
+    for(std::size_t j = 0; j < _eigenVectors[i].size(); j++) {
       _eigenVectors[i][j] *= (scale / norm);
     }
   }
