@@ -220,9 +220,7 @@ HXTStatus hxtTetReorder(HXTMesh* mesh)
   for (uint64_t i=0; i<nTet; i++) {
     uint64_t index = pair[i].v[1];
     uint32_t* oldNode = mesh->tetrahedra.node + 4*index;
-#if !defined(HAVE_NO_OPENMP_SIMD)
-    #pragma omp simd aligned(newNode:SIMD_ALIGN) aligned(oldNode:16)
-#endif
+    #pragma omp simd aligned(newNode:SIMD_ALIGN)
     for (unsigned j=0; j<4; j++)
       newNode[i*4+j] = oldNode[j]; 
   }
@@ -340,6 +338,12 @@ HXTStatus hxtTetVerify(HXTMesh* mesh)
         continue;
       }
 
+      if(getDeletedFlag(mesh, neigh)) {
+        HXT_ERROR_MSG(HXT_STATUS_ERROR, "%uth neighbor of tet %lu is deleted", j, i);
+        errorOccured=1;
+        continue;
+      }
+
       // uint64_t* NeighNeigh = mesh->tetrahedra.neigh + neigh;
       uint32_t* NeighNode = mesh->tetrahedra.node + neigh*4;
       
@@ -538,4 +542,4 @@ HXTStatus hxtAddGhosts(HXTMesh* mesh){
   HXT_CHECK( hxtFree(&hullCount) );
 
   return HXT_STATUS_OK;
-}
+}
\ No newline at end of file
