@@ -1,7 +1,7 @@
 import gmsh
 import math
-import thread
 import time
+import threading
 
 # This example shows how to implement a custom user interface running
 # computationally expensive calculations in separate threads. The threads can
@@ -17,8 +17,8 @@ gmsh.option.setNumber("General.ShowModuleMenu", 0)
 # it will set the "ONELAB/Action" parameter to "should compute")
 parameters = """
 [
-  { "type":"number", "name":"My App/Iterations", "values":[1e6],
-    "attributes":{"Highlight":"AliceBlue"} },
+  { "type":"number", "name":"My App/Iterations", "values":[1e6], "min":1e4,
+    "max":1e9, "step":1e5, "attributes":{"Highlight":"AliceBlue"} },
   { "type":"number", "name":"My App/Number of threads", "values":[2],
     "min":1, "max":16, "step":1, "attributes":{"Highlight":"AliceBlue"} },
   { "type":"number", "name":"My App/Show progress?", "values":[1],
@@ -68,6 +68,10 @@ def compute(arg):
 gmsh.fltk.initialize()
 
 while 1:
+    # check if GUI has been closed
+    if gmsh.fltk.isAvailable() == 0:
+        break
+
     # wait for an event
     gmsh.fltk.wait()
 
@@ -84,7 +88,9 @@ while 1:
         # start computationally intensive calculations in their own threads
         n = int(gmsh.onelab.getNumber("My App/Number of threads")[0])
         for i in range(n):
-            thread.start_new_thread(compute, ("My App/Thread {0}".format(i + 1),))
+            t = threading.Thread(target=compute,
+                                 args=("My App/Thread {0}".format(i + 1),))
+            t.start()
     elif action[0] == "should stop":
         stop_computation = True
     elif action[0] == "done computing":
